@@ -287,7 +287,6 @@ def create_inbox_message(message_type=None, subject=None, patient=None, staff=No
 		'subject': subject
 	}
 	rows, idx = gmPG2.run_rw_queries(queries = [{'cmd': cmd, 'args': args}], return_data = True, get_col_idx = False)
-
 	return cInboxMessage(aPK_obj = rows[0]['pk'])
 
 #------------------------------------------------------------
@@ -349,7 +348,7 @@ class cProviderInbox:
 	def delete_message(self, pk=None):
 		return delete_inbox_message(inbox_message = pk)
 	#--------------------------------------------------------
-	def add_message(message_type=None, subject=None, patient=None):
+	def add_message(self, message_type=None, subject=None, patient=None):
 		return create_inbox_message (
 			message_type = message_type,
 			subject = subject,
