@@ -276,6 +276,16 @@ def connect_to_database(max_attempts=3, expected_version=None, require_version=T
 				connected = False
 				continue
 
+		user_needs_pwd_enc_switch = gmPG2.user_needs_password_encryption_switch()
+		if user_needs_pwd_enc_switch:
+			gmGuiHelpers.gm_show_warning (
+				aTitle = _('Verifying password security'),
+				aMessage = _(
+					'For improved password security please\n'
+					'arrange for your password to be re-set.'
+				)
+			)
+
 		gmExceptionHandlingWidgets.set_is_public_database(_cfg.get(option = 'is_public_db'))
 		gmExceptionHandlingWidgets.set_helpdesk(_cfg.get(option = 'helpdesk'))
 
@@ -507,7 +517,7 @@ class cLoginPanel(wx.Panel):
 		# FIXME: why doesn't this align in the centre ?
 		self.paramsbox = wx.StaticBox( self, -1, paramsbox_caption, style = wx.ALIGN_CENTRE_HORIZONTAL)
 		self.paramsboxsizer = wx.StaticBoxSizer( self.paramsbox, wx.VERTICAL )
-		self.paramsbox.SetForegroundColour(wx.Colour(35, 35, 142))
+		self.__set_label_color(self.paramsbox)  # set color according to background
 		self.paramsbox.SetFont(wx.Font(
 			pointSize = 12,
 			family = wx.SWISS,
@@ -520,7 +530,7 @@ class cLoginPanel(wx.Panel):
 
 		# PROFILE COMBO
 		label = wx.StaticText( self, -1, _('Log into'), wx.DefaultPosition, wx.DefaultSize, 0)
-		label.SetForegroundColour(wx.Colour(35, 35, 142))
+		self.__set_label_color(label)  # set color according to dark/light theme
 		self.pboxgrid.Add(label, 0, wx.ALIGN_CENTER_VERTICAL | wx.ALL, 5)
 		self.__backend_profiles = self.__get_backend_profiles()
 		self._CBOX_profile = wx.ComboBox (
@@ -536,7 +546,7 @@ class cLoginPanel(wx.Panel):
 
 		# USER NAME COMBO
 		label = wx.StaticText( self, -1, _("Username"), wx.DefaultPosition, wx.DefaultSize, 0 )
-		label.SetForegroundColour(wx.Colour(35, 35, 142))
+		self.__set_label_color(label)  # set color according to dark/light theme
 		self.pboxgrid.Add(label, 0, wx.ALIGN_CENTER_VERTICAL|wx.ALL, 5 )
 		self.__previously_used_accounts = self.__get_previously_used_accounts()
 		self._CBOX_user = wx.ComboBox (
@@ -552,7 +562,7 @@ class cLoginPanel(wx.Panel):
 
 		#PASSWORD TEXT ENTRY
 		label = wx.StaticText( self, -1, _("Password"), wx.DefaultPosition, wx.DefaultSize, 0 )
-		label.SetForegroundColour(wx.Colour(35, 35, 142))
+		self.__set_label_color(label)  # set color according to dark/light theme
 		self.pboxgrid.Add( label, 0, wx.ALIGN_CENTER_VERTICAL|wx.ALL, 5 )
 		self.pwdentry = wx.TextCtrl( self, 1, '', wx.DefaultPosition, wx.Size(80,-1), wx.TE_PASSWORD )
 		# set focus on password entry
@@ -561,7 +571,7 @@ class cLoginPanel(wx.Panel):
 
 		# --debug checkbox
 		label = wx.StaticText(self, -1, _('Options'), wx.DefaultPosition, wx.DefaultSize, 0)
-		label.SetForegroundColour(wx.Colour(35, 35, 142))
+		self.__set_label_color(label)  # set color according to dark/light theme
 		self.pboxgrid.Add(label, 0, wx.ALIGN_CENTER_VERTICAL|wx.ALL, 5)
 		self._CHBOX_debug = wx.CheckBox(self, -1, _('&Debug mode'))
 		self._CHBOX_debug.SetToolTip(_('Check this to run GNUmed client in debugging mode.'))
@@ -569,7 +579,7 @@ class cLoginPanel(wx.Panel):
 
 		# --slave checkbox
 		label = wx.StaticText(self, -1, '', wx.DefaultPosition, wx.DefaultSize, 0)
-		label.SetForegroundColour(wx.Colour(35, 35, 142))
+		self.__set_label_color(label)  # set color according to dark/light theme
 		self.pboxgrid.Add(label, 0, wx.ALIGN_CENTER_VERTICAL|wx.ALL, 5)
 		self._CHBOX_slave = wx.CheckBox(self, -1, _('Enable &remote control'))
 		self._CHBOX_slave.SetToolTip(_('Check this to run GNUmed client in slave mode for remote control.'))
@@ -637,6 +647,12 @@ class cLoginPanel(wx.Panel):
 	#----------------------------------------------------------
 	# internal helper methods
 	#----------------------------------------------------------
+	def __set_label_color(self, label):
+		"""Set adaptive label color based on system theme background."""
+		if not gmGuiHelpers.is_probably_dark_theme():
+			label.SetForegroundColour(wx.Colour(35, 35, 142))  # orig dark blue
+
+	#----------------------------------------------------
 	def __get_previously_used_accounts(self):
 
 		accounts = gmTools.coalesce (
