@@ -19,7 +19,7 @@ _log = logging.getLogger('gm.ui')
 class gmEMRListJournalPlugin(gmPlugin.cNotebookPlugin):
 	"""Plugin to encapsulate patient EMR list based Journal window."""
 
-	tab_name = _('EMR Journal')
+	tab_name = _('EMR List')
 	required_minimum_role = 'full clinical access'
 
 	#-------------------------------------------------
@@ -43,7 +43,7 @@ class gmEMRListJournalPlugin(gmPlugin.cNotebookPlugin):
 
 	#-------------------------------------------------
 	def MenuInfo (self):
-		return ('emr', _('EMR &Journal (list)'))
+		return ('emr', _('EMR: &List Journal'))
 
 	#-------------------------------------------------
 	def can_receive_focus(self):
